vfbLib.parsers.numeric.DoubleListParser
=======================================

.. currentmodule:: vfbLib.parsers.numeric

.. autoclass:: DoubleListParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DoubleListParser.__init__
      ~DoubleListParser.parse
      ~DoubleListParser.parse_hex
      ~DoubleListParser.read_double
      ~DoubleListParser.read_doubles
      ~DoubleListParser.read_float
      ~DoubleListParser.read_floats
      ~DoubleListParser.read_int16
      ~DoubleListParser.read_int32
      ~DoubleListParser.read_int8
      ~DoubleListParser.read_str
      ~DoubleListParser.read_str_all
      ~DoubleListParser.read_uint16
      ~DoubleListParser.read_uint32
      ~DoubleListParser.read_uint8
      ~DoubleListParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DoubleListParser.encoding
      ~DoubleListParser.master_count
      ~DoubleListParser.stream
      ~DoubleListParser.ttStemsH_count
      ~DoubleListParser.ttStemsV_count
   
   